@@ -2,6 +2,9 @@
 -- This ensures the status column always has a valid default value
 -- preventing "Column 'status' cannot be null" errors
 
+-- Select the WHP database
+USE whp;
+
 -- Modify the backup_history table to ensure status has proper default
 ALTER TABLE backup_history
 MODIFY COLUMN status ENUM('pending', 'running', 'completed', 'failed', 'deleted') NOT NULL DEFAULT 'pending';
